*-------------------------------------------------------------------------------

/*
TITLE: Bootstrapping

DESCRIPTION: Performs wild bootstrap tests for Tables III-V

*/

*-------------------------------------------------------------------------------


version 13
clear
set more off
*cd "directory where the dataset is" 
use "Main_data.dta"
capture log close
capture log using "wildbootstrapping.log", replace

//Generates dummy variables corresponding to every value of classroom and surveyor
tabulate classroom, generate(iclass)
tabulate surveyor, generate(isurveyor)

***** TABLE III- Main - Separated

*COLUMN 1 

cgmwildboot yesno public if honor==0 , cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 2 

cgmwildboot yesno public male age hispanic if honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 3

cgmwildboot yesno public male age hispanic iclass* isurv* if honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 4

cgmwildboot yesno public if honor==1 , cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 5

cgmwildboot yesno public   male age hispanic if honor==1, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 6

cgmwildboot yesno public  male age hispanic iclass* isurv* if honor==1, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

****** TABLE IV-  Pooled some honors, Effect of Public Treatment on Sign-up Decision for Students 1-3 Honors Classes

gen one_hon=honor_ap_to==1
gen two_hon=honor_ap_to==2
gen three_hon=honor_ap_to==3
gen four_hon=honor_ap_to==4

replace one_hon=. if honor_ap_to==.
replace two_hon=. if honor_ap_to==.
replace three_hon=. if honor_ap_to==.
replace four_hon=. if honor_ap_to==.


gen one_honXhon = one_hon*honor
gen two_honXhon = two_hon*honor
gen three_honXhon = three_hon*honor



*COLUMN 1

cgmwildboot yesno public one_hon two_hon three_hon if honor_ap_to>0 & honor_ap_to<4 & honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 2

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic if honor_ap_to>0 & honor_ap_to<4 & honor==0,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 3

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic  iclass* isurv* if honor_ap_to>0 & honor_ap_to<4 & honor==0,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 4

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic total_honor_ms  total_honor_sosci iclass* isurv* if honor_ap_to>0 & honor_ap_to<4 & honor==0,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 5

cgmwildboot yesno public one_hon two_hon three_hon  if honor_ap_to>0 & honor_ap_to<4 & honor==1,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 6

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic if honor_ap_to>0 & honor_ap_to<4 & honor==1,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 7

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic  iclass* isurv* if honor_ap_to>0 & honor_ap_to<4 & honor==1,  cluster(classroom_id) bootcluster(classroom_id) seed(1000) 

*COLUMN 8

cgmwildboot yesno public one_hon two_hon three_hon male age hispanic total_honor_ms  total_honor_sosci iclass* isurv* if honor_ap_to>0 & honor_ap_to<4 & honor==1,  cluster(classroom_id) bootcluster(classroom_id) seed(1000)  




***** TABLE V - Popularity: Effect of Public Treatment on Sign-up Decision
**** Public x not important to be popular (A); Public x important to be popular (B)


gen publicXimportant=public*important
gen publicXnot=public*(1-important)


//regular
cgmwildboot yesno important publicXnot publicXimportant if honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 
cgmwildboot yesno important publicXnot publicXimportant male age hispanic if honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 
cgmwildboot yesno important publicXnot publicXimportant  male age hispanic iclass* isurv* if honor==0, cluster(classroom_id) bootcluster(classroom_id) seed(1000)  


//honor
cgmwildboot yesno important publicXnot publicXimportant if honor==1, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 
cgmwildboot yesno important publicXnot publicXimportant male age hispanic if honor==1, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 
cgmwildboot yesno important publicXnot publicXimportant male age hispanic iclass* isurv* if honor==1, cluster(classroom_id) bootcluster(classroom_id) seed(1000) 
